summaryrefslogtreecommitdiffstats
path: root/crypto/bio/bss_bio.c
diff options
context:
space:
mode:
authorBodo Möller <bodo@openssl.org>1999-06-07 20:34:36 +0000
committerBodo Möller <bodo@openssl.org>1999-06-07 20:34:36 +0000
commit3928b6bf4815d5f9d9cf1af10dea84e27a74ccb2 (patch)
tree5b0dc85aa8f45440e9b5d4f6a7defef45ed60f52 /crypto/bio/bss_bio.c
parentb1c4fe36258dde2950f59fec5d5f86743e495d9d (diff)
treat init properly
Diffstat (limited to 'crypto/bio/bss_bio.c')
-rw-r--r--crypto/bio/bss_bio.c6
1 files changed, 5 insertions, 1 deletions
diff --git a/crypto/bio/bss_bio.c b/crypto/bio/bss_bio.c
index 5b60f541a1..84b91b5778 100644
--- a/crypto/bio/bss_bio.c
+++ b/crypto/bio/bss_bio.c
@@ -46,7 +46,8 @@ struct bio_bio_st
{
BIO *peer; /* NULL if buf == NULL.
* If peer != NULL, then peer->ptr is also a bio_bio_st,
* and its "peer" member points back to us. */
/* This is for what we write (i.e. reading uses peer's struct): */
int closed; /* valid iff peer != NULL */
@@ -224,6 +225,9 @@ static int bio_make_pair(BIO *bio1, BIO *bio2)
b1->peer = bio2;
b2->peer = bio1;
+ bio1->init = 1;
+ bio2->init = 1;
+
return 1;
}
@@ -46,7 +46,8 @@ struct bio_bio_st
BIO *peer; /* NULL if buf == NULL.
* If peer != NULL, then peer->ptr is also a bio_bio_st,
- * and its "peer" member points back to us. */
+ * and its "peer" member points back to us.
+ * peer != NULL iff init != 0 in the BIO. */
/* This is for what we write (i.e. reading uses peer's struct): */
int closed; /* valid iff peer != NULL */